@@ -21,10 +21,13 @@ import io.netty.buffer.ByteBufUtil;
 import io.netty.util.ReferenceCountUtil;
 
 import java.io.IOException;
+import java.lang.reflect.Field;
 import java.net.URI;
 import java.nio.ByteBuffer;
+import java.security.Principal;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
+import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.ThreadFactory;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
@@ -54,11 +57,13 @@ import org.apache.qpid.jms.provider.ProviderClosedException;
 import org.apache.qpid.jms.provider.ProviderConstants.ACK_TYPE;
 import org.apache.qpid.jms.provider.ProviderFuture;
 import org.apache.qpid.jms.provider.ProviderListener;
+import org.apache.qpid.jms.transports.SSLTransport;
 import org.apache.qpid.jms.transports.TransportFactory;
 import org.apache.qpid.jms.transports.TransportListener;
 import org.apache.qpid.jms.util.IOExceptionSupport;
 import org.apache.qpid.proton.engine.Collector;
 import org.apache.qpid.proton.engine.Connection;
+import org.apache.qpid.proton.engine.EndpointState;
 import org.apache.qpid.proton.engine.Event;
 import org.apache.qpid.proton.engine.Event.Type;
 import org.apache.qpid.proton.engine.Sasl;
@@ -99,8 +104,11 @@ public class AmqpProvider implements Provider, TransportListener {
     private AmqpConnection connection;
     private org.apache.qpid.jms.transports.Transport transport;
     private String transportType = AmqpProviderFactory.DEFAULT_TRANSPORT_TYPE;
+    private String vhost;
     private boolean traceFrames;
     private boolean traceBytes;
+    private boolean saslLayer = true;
+    private String[] saslMechanisms;
     private boolean presettleConsumers;
     private boolean presettleProducers;
     private long connectTimeout = JmsConnectionInfo.DEFAULT_CONNECT_TIMEOUT;
@@ -108,6 +116,9 @@ public class AmqpProvider implements Provider, TransportListener {
     private long requestTimeout = JmsConnectionInfo.DEFAULT_REQUEST_TIMEOUT;
     private long sendTimeout = JmsConnectionInfo.DEFAULT_SEND_TIMEOUT;
     private int channelMax = DEFAULT_CHANNEL_MAX;
+    private int idleTimeout = 60000;
+    private long sessionOutoingWindow = -1; //Use proton default
+    private int maxFrameSize = DEFAULT_MAX_FRAME_SIZE;
 
     private final URI remoteURI;
     private final AtomicBoolean closed = new AtomicBoolean();
@@ -115,6 +126,8 @@ public class AmqpProvider implements Provider, TransportListener {
     private final Transport protonTransport = Transport.Factory.create();
     private final Collector protonCollector = new CollectorImpl();
 
+    private ScheduledFuture<?> nextIdleTimeoutCheck;
+
     /**
      * Create a new instance of an AmqpProvider bonded to the given remote URI.
      *
@@ -185,6 +198,12 @@ public class AmqpProvider implements Provider, TransportListener {
                         }
                     } catch (Exception e) {
                         LOG.debug("Caught exception while closing proton connection: {}", e.getMessage());
+                    } finally {
+                        if (nextIdleTimeoutCheck != null) {
+                            LOG.trace("Cancelling scheduled IdleTimeoutCheck");
+                            nextIdleTimeoutCheck.cancel(false);
+                            nextIdleTimeoutCheck = null;
+                        }
                     }
                 }
             });
@@ -250,15 +269,33 @@ public class AmqpProvider implements Provider, TransportListener {
                             requestTimeout = connectionInfo.getRequestTimeout();
 
                             Connection protonConnection = Connection.Factory.create();
-                            protonTransport.setMaxFrameSize(getMaxFrameSize());
+
+                            if(getMaxFrameSize() > 0) {
+                                protonTransport.setMaxFrameSize(getMaxFrameSize());
+                            }
                             protonTransport.setChannelMax(getChannelMax());
+                            protonTransport.setIdleTimeout(idleTimeout);
                             protonTransport.bind(protonConnection);
                             protonConnection.collect(protonCollector);
-                            Sasl sasl = protonTransport.sasl();
-                            if (sasl != null) {
+
+                            AmqpSaslAuthenticator authenticator = null;
+                            if (saslLayer) {
+                                Sasl sasl = protonTransport.sasl();
                                 sasl.client();
+
+                                String hostname = getVhost();
+                                if(hostname == null) {
+                                    hostname = remoteURI.getHost();
+                                } else if (hostname.isEmpty()) {
+                                    hostname = null;
+                                }
+
+                                setHostname(sasl, hostname);
+
+                                authenticator = new AmqpSaslAuthenticator(sasl, connectionInfo, getLocalPrincipal(), saslMechanisms);
                             }
-                            connection = new AmqpConnection(AmqpProvider.this, protonConnection, sasl, connectionInfo);
+
+                            connection = new AmqpConnection(AmqpProvider.this, protonConnection, authenticator, connectionInfo);
                             connection.open(new AsyncResult() {
 
                                 @Override
@@ -634,7 +671,9 @@ public class AmqpProvider implements Provider, TransportListener {
 
             @Override
             public void run() {
-                LOG.trace("Received from Broker {} bytes: {}", input.readableBytes(), input);
+                if (isTraceBytes()) {
+                    TRACE_BYTES.info("Received: {}", ByteBufUtil.hexDump(input));
+                }
 
                 ByteBuffer source = input.nioBuffer();
 
@@ -734,12 +773,10 @@ public class AmqpProvider implements Provider, TransportListener {
                         amqpResource.processRemoteOpen(this);
                         break;
                     case LINK_REMOTE_CLOSE:
-                        LOG.info("Link closed: {}", protonEvent.getLink().getContext());
                         amqpResource = (AmqpResource) protonEvent.getLink().getContext();
                         amqpResource.processRemoteClose(this);
                         break;
                     case LINK_REMOTE_DETACH:
-                        LOG.info("Link detach: {}", protonEvent.getLink().getContext());
                         amqpResource = (AmqpResource) protonEvent.getLink().getContext();
                         amqpResource.processRemoteDetach(this);
                         break;
@@ -772,7 +809,7 @@ public class AmqpProvider implements Provider, TransportListener {
         }
     }
 
-    private void pumpToProtonTransport(AsyncResult request) {
+    private boolean pumpToProtonTransport(AsyncResult request) {
         try {
             boolean done = false;
             while (!done) {
@@ -794,10 +831,22 @@ public class AmqpProvider implements Provider, TransportListener {
         } catch (IOException e) {
             fireProviderException(e);
             request.onFailure(e);
+            return false;
         }
+
+        return true;
     }
 
     void fireConnectionEstablished() {
+
+        long now = System.currentTimeMillis();
+        long deadline = protonTransport.tick(now);
+        if (deadline > 0) {
+            long delay = deadline - now;
+            LOG.trace("IdleTimeoutCheck being initiated, initial delay: {}", delay);
+            nextIdleTimeoutCheck = serializer.schedule(new IdleTimeoutCheck(), delay, TimeUnit.MILLISECONDS);
+        }
+
         ProviderListener listener = this.listener;
         if (listener != null) {
             listener.onConnectionEstablished(remoteURI);
@@ -851,6 +900,94 @@ public class AmqpProvider implements Provider, TransportListener {
         return this.traceBytes;
     }
 
+    public boolean isSaslLayer() {
+        return saslLayer;
+    }
+
+    /**
+     * Sets whether a sasl layer is used for the connection or not.
+     *
+     * @param saslLayer true to enable the sasl layer, false to disable it.
+     */
+    public void setSaslLayer(boolean saslLayer) {
+        this.saslLayer = saslLayer;
+    }
+
+    public String[] getSaslMechanisms() {
+        return saslMechanisms;
+    }
+
+    /**
+     * Sets a selection of mechanisms to restrict the choice to, enabling only
+     * a subset of the servers offered mechanisms to be selectable.
+     *
+     * @param saslMechanisms the mechanisms to restrict choice to, or null not to restrict.
+     */
+    public void setSaslMechanisms(String[] saslMechanisms) {
+        this.saslMechanisms = saslMechanisms;
+    }
+
+    public String getVhost() {
+        return vhost;
+    }
+
+    /**
+     * Sets the hostname to be used in the AMQP SASL Init and Open frames.
+     *
+     * If set null, the host provided in the remoteURI will be used. If set to
+     * the empty string, the hostname field of the frames will be cleared.
+     *
+     * @param vhost the hostname to include in SASL Init and Open frames.
+     */
+    public void setVhost(String vhost) {
+        this.vhost = vhost;
+    }
+
+    public int getIdleTimeout() {
+        return idleTimeout;
+    }
+
+    /**
+     * Sets the idle timeout (in milliseconds) after which the connection will
+     * be closed if the peer has not send any data. The provided value will be
+     * halved before being transmitted as our advertised idle-timeout in the
+     * AMQP Open frame.
+     *
+     * @param idleTimeout the timeout in milliseconds.
+     */
+    public void setIdleTimeout(int idleTimeout) {
+        this.idleTimeout = idleTimeout;
+    }
+
+    public int getMaxFrameSize() {
+        return maxFrameSize;
+    }
+
+    /**
+     * Sets the max frame size (in bytes).
+     *
+     * Values of -1 indicates to use the proton default.
+     *
+     * @param maxFrameSize the frame size in bytes.
+     */
+    public void setMaxFrameSize(int maxFrameSize) {
+        this.maxFrameSize = maxFrameSize;
+    }
+
+    public long getSessionOutgoingWindow() {
+        return sessionOutoingWindow;
+    }
+
+    /**
+     * Sets the outgoing window size for the AMQP session. Values may
+     * be between -1 and 2^32-1, where -1 indicates to use the default.
+     *
+     * @param sessionOutoingWindow the outgoing window size
+     */
+    public void setSessionOutgoingWindow(long sessionOutoingWindow) {
+        this.sessionOutoingWindow = sessionOutoingWindow;
+    }
+
     public long getCloseTimeout() {
         return this.closeTimeout;
     }
@@ -888,13 +1025,6 @@ public class AmqpProvider implements Provider, TransportListener {
         this.presettleProducers = presettle;
     }
 
-    /**
-     * @return the currently set Max Frame Size value.
-     */
-    public int getMaxFrameSize() {
-        return DEFAULT_MAX_FRAME_SIZE;
-    }
-
     @Override
     public String toString() {
         return "AmqpProvider: " + getRemoteURI().getHost() + ":" + getRemoteURI().getPort();
@@ -930,4 +1060,58 @@ public class AmqpProvider implements Provider, TransportListener {
     public URI getRemoteURI() {
         return remoteURI;
     }
+
+    private final class IdleTimeoutCheck implements Runnable {
+        @Override
+        public void run() {
+            boolean checkScheduled = false;
+
+            if (connection.getLocalState() == EndpointState.ACTIVE) {
+                long now = System.currentTimeMillis();
+                long deadline = protonTransport.tick(now);
+
+                boolean pumpSucceeded = pumpToProtonTransport(NOOP_REQUEST);
+
+                if (protonTransport.isClosed()) {
+                    LOG.info("IdleTimeoutCheck closed the transport due to the peer exceeding our requested idle-timeout.");
+                    if (pumpSucceeded) {
+                        fireProviderException(new IOException("Transport closed due to the peer exceeding our requested idle-timeout"));
+                    }
+                } else {
+                    if (deadline > 0) {
+                        long delay = deadline - now;
+                        checkScheduled = true;
+                        LOG.trace("IdleTimeoutCheck rescheduling with delay: {}", delay);
+                        nextIdleTimeoutCheck = serializer.schedule(this, delay, TimeUnit.MILLISECONDS);
+                    }
+                }
+            } else {
+                LOG.trace("IdleTimeoutCheck skipping check, connection is not active.");
+            }
+
+            if(!checkScheduled) {
+                nextIdleTimeoutCheck = null;
+                LOG.trace("IdleTimeoutCheck exiting");
+            }
+        }
+    }
+
+    Principal getLocalPrincipal() {
+        if(transport instanceof SSLTransport) {
+            return ((SSLTransport) transport).getLocalPrincipal();
+        }
+
+        return null;
+    }
+
+    private static void setHostname(Sasl sasl, String hostname) {
+        //TODO: this is a hack until Proton 0.10+ is available with sasl#setHostname method.
+        try {
+            Field field = sasl.getClass().getDeclaredField("_hostname");
+            field.setAccessible(true);
+            field.set(sasl, hostname);
+        } catch (Exception e) {
+            LOG.trace("Failed to set SASL hostname", e);
+        }
+    }
 }
