@@ -16,6 +16,8 @@
  */
 package org.apache.qpid.jms.sasl;
 
+import java.security.Principal;
+
 /**
  * Implements the Anonymous SASL authentication mechanism.
  */
@@ -40,4 +42,9 @@ public class AnonymousMechanism extends AbstractMechanism {
     public String getName() {
         return "ANONYMOUS";
     }
+
+    @Override
+    public boolean isApplicable(String username, String password, Principal localPrincipal) {
+        return true;
+    }
 }
