@@ -115,7 +115,7 @@ public class NettyTcpTransport implements Transport {
 
         configureNetty(bootstrap, getTransportOptions());
 
-        ChannelFuture future = bootstrap.connect(remote.getHost(), remote.getPort());
+        ChannelFuture future = bootstrap.connect(getRemoteHost(), getRemotePort());
         future.addListener(new ChannelFutureListener() {
 
             @Override
@@ -216,6 +216,14 @@ public class NettyTcpTransport implements Transport {
 
     //----- Internal implementation details, can be overridden as needed --//
 
+    protected String getRemoteHost() {
+        return remote.getHost();
+    }
+
+    protected int getRemotePort() {
+        return remote.getPort() != -1 ? remote.getPort() : getTransportOptions().getDefaultTcpPort();
+    }
+
     protected void configureNetty(Bootstrap bootstrap, TransportOptions options) {
         bootstrap.option(ChannelOption.TCP_NODELAY, options.isTcpNoDelay());
         bootstrap.option(ChannelOption.CONNECT_TIMEOUT_MILLIS, options.getConnectTimeout());
