@@ -40,9 +40,13 @@ import javax.jms.JMSException;
 
 import org.apache.qpid.jms.test.QpidJmsTestCase;
 import org.junit.Test;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 public class JmsConnectionFactoryTest extends QpidJmsTestCase {
 
+    private static final Logger LOG = LoggerFactory.getLogger(JmsConnectionFactoryTest.class);
+
     private static final String CLIENT_ID_PROP = "clientID";
     private static final String QUEUE_PREFIX_PROP = "queuePrefix";
     private static final String TOPIC_PREFIX_PROP = "topicPrefix";
@@ -340,6 +344,35 @@ public class JmsConnectionFactoryTest extends QpidJmsTestCase {
         assertEquals("Properties were not equal", props, props2);
     }
 
+    /**
+     * The redelivery policy is maintained in a child-object, which we extract the properties from
+     * when serializing the factory. Ensure this functions by doing a round trip on a factory
+     * configured with some new redelivery configuration via the URI.
+     */
+    @Test
+    public void testSerializeThenDeserializeMaintainsRedeliveryPolicy() throws Exception {
+        String maxRedeliveryValue = "5";
+        String maxRedeliveryKey = "redeliveryPolicy.maxRedeliveries";
+        String uri = "amqp://localhost:1234?jms." + maxRedeliveryKey + "=" + maxRedeliveryValue;
+
+        JmsConnectionFactory cf = new JmsConnectionFactory(uri);
+        Map<String, String> props = cf.getProperties();
+
+        assertTrue("Props dont contain expected redelivery policy change", props.containsKey(maxRedeliveryKey));
+        assertEquals("Unexpected value", maxRedeliveryValue, props.get(maxRedeliveryKey));
+
+        Object roundTripped = roundTripSerialize(cf);
+
+        assertNotNull("Null object returned", roundTripped);
+        assertEquals("Unexpected type", JmsConnectionFactory.class, roundTripped.getClass());
+
+        Map<String, String> props2 = ((JmsConnectionFactory)roundTripped).getProperties();
+        assertTrue("Props dont contain expected redelivery policy change", props2.containsKey(maxRedeliveryKey));
+        assertEquals("Unexpected value", maxRedeliveryValue, props2.get(maxRedeliveryKey));
+
+        assertEquals("Properties were not equal", props, props2);
+    }
+
     @Test
     public void testSerializeTwoConnectionFactories() throws Exception {
         String uri = "amqp://localhost:1234";
@@ -398,4 +431,25 @@ public class JmsConnectionFactoryTest extends QpidJmsTestCase {
         assertFalse("Properties map should not contain ExceptionListener", props.containsKey("exceptionListener"));
         assertEquals("Properties were not equal", props, props2);
     }
+
+    @Test(timeout = 5000)
+    public void testCreateConnectionWithPortOutOfRange() throws Exception {
+        JmsConnectionFactory factory = new JmsConnectionFactory("amqp://127.0.0.1:567564562");
+
+        try {
+            factory.createConnection();
+            fail("Should have thrown exception");
+        } catch (JMSException jmse) {
+            LOG.debug("Caught Ex -> ", jmse);
+        }
+
+        factory = new JmsConnectionFactory("amqp://127.0.0.1:5675645622");
+
+        try {
+            factory.createConnection();
+            fail("Should have thrown exception");
+        } catch (JMSException jmse) {
+            LOG.debug("Caught Ex -> ", jmse);
+        }
+    }
 }
