@@ -49,12 +49,12 @@ public class IdleTimeoutIntegrationTest extends QpidJmsTestCase {
 
     public static final Logger LOGGER = LoggerFactory.getLogger(IdleTimeoutIntegrationTest.class);
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testIdleTimeoutIsAdvertisedByDefault() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
-            testPeer.expectAnonymousConnect(true, greaterThan(UnsignedInteger.valueOf(0)), null);
+            testPeer.expectSaslAnonymousConnect(greaterThan(UnsignedInteger.valueOf(0)), null);
             // Each connection creates a session for managing temporary destinations etc
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
 
             ConnectionFactory factory = new JmsConnectionFactory("amqp://localhost:" + testPeer.getServerPort());
             Connection connection = factory.createConnection();
@@ -69,15 +69,15 @@ public class IdleTimeoutIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testAdvertisedIdleTimeoutIsHalfOfActualTimeoutValue() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             int configuredTimeout = 54320;
             int advertisedValue = configuredTimeout / 2;
 
-            testPeer.expectAnonymousConnect(true, equalTo(UnsignedInteger.valueOf(advertisedValue)), null);
+            testPeer.expectSaslAnonymousConnect(equalTo(UnsignedInteger.valueOf(advertisedValue)), null);
             // Each connection creates a session for managing temporary destinations etc
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
 
             ConnectionFactory factory = new JmsConnectionFactory("amqp://localhost:" + testPeer.getServerPort() + "?amqp.idleTimeout=" + configuredTimeout);
             Connection connection = factory.createConnection();
@@ -92,7 +92,7 @@ public class IdleTimeoutIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testClientSendsEmptyFramesWhenPeerAdvertisesIdleTimeout() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             int period = 20;
@@ -101,9 +101,9 @@ public class IdleTimeoutIntegrationTest extends QpidJmsTestCase {
 
             testPeer.setAdvertisedIdleTimeout(advertisedTimeout);
 
-            testPeer.expectAnonymousConnect(true);
+            testPeer.expectSaslAnonymousConnect();
             // Each connection creates a session for managing temporary destinations etc
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
 
             ConnectionFactory factory = new JmsConnectionFactory("amqp://localhost:" + testPeer.getServerPort());
             Connection connection = factory.createConnection();
@@ -128,7 +128,7 @@ public class IdleTimeoutIntegrationTest extends QpidJmsTestCase {
 
     //TODO: Could use JUnit categories to make this slowish test skipable?
     //      If so, make it slower still and more granular.
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testClientSendsEmptyFramesWithExpectedFrequency() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             int period = 250;
@@ -139,9 +139,9 @@ public class IdleTimeoutIntegrationTest extends QpidJmsTestCase {
 
             testPeer.setAdvertisedIdleTimeout(advertisedTimeout);
 
-            testPeer.expectAnonymousConnect(true);
+            testPeer.expectSaslAnonymousConnect();
             // Each connection creates a session for managing temporary destinations etc
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
 
             ConnectionFactory factory = new JmsConnectionFactory("amqp://localhost:" + testPeer.getServerPort());
             Connection connection = factory.createConnection();
@@ -163,14 +163,14 @@ public class IdleTimeoutIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testConnectionSetFailedWhenPeerNeglectsToSendEmptyFrames() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             int configuredTimeout = 200;
 
-            testPeer.expectAnonymousConnect(true);
+            testPeer.expectSaslAnonymousConnect();
             // Each connection creates a session for managing temporary destinations etc
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
 
             JmsConnectionFactory factory = new JmsConnectionFactory("amqp://localhost:" + testPeer.getServerPort() + "?amqp.idleTimeout=" + configuredTimeout);
             final JmsConnection connection = (JmsConnection) factory.createConnection();
@@ -188,13 +188,13 @@ public class IdleTimeoutIntegrationTest extends QpidJmsTestCase {
                 public boolean isSatisified() throws Exception {
                     return connection.isFailed();
                 }
-            }, configuredTimeout * 2, 10);
+            }, 10000, 10);
 
             assertTrue("connection didnt fail in expected timeframe", failed);
         }
     }
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testConnectionNotMarkedFailedWhenPeerSendsEmptyFrames() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             int configuredTimeout = 1000;
@@ -203,9 +203,9 @@ public class IdleTimeoutIntegrationTest extends QpidJmsTestCase {
 
             final CountDownLatch latch = new CountDownLatch(cycles);
 
-            testPeer.expectAnonymousConnect(true);
+            testPeer.expectSaslAnonymousConnect();
             // Each connection creates a session for managing temporary destinations etc
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
 
             // Start to emit idle frames when the connection is set up, this should stop it timing out
             testPeer.runAfterLastHandler(new EmptyFrameSender(latch, period, cycles, testPeer));
