@@ -62,17 +62,17 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase
 
     //==== Java serialization encoding ====
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testSendBasicObjectMessageWithSerializedContent() throws Exception {
         doSendBasicObjectMessageWithSerializedContentTestImpl("myObjectString", false);
     }
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testSendBasicObjectMessageWithSerializedContentExplicitNull() throws Exception {
         doSendBasicObjectMessageWithSerializedContentTestImpl(null, true);
     }
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testSendBasicObjectMessageWithSerializedContentImplicitNull() throws Exception {
         doSendBasicObjectMessageWithSerializedContentTestImpl(null, false);
     }
@@ -80,7 +80,7 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase
     private void doSendBasicObjectMessageWithSerializedContentTestImpl(String content, boolean setObjectIfNull) throws JMSException, IOException, InterruptedException, Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -118,13 +118,13 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase
         }
     }
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testReceiveBasicObjectMessageWithSerializedContent() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
             connection.start();
 
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
             Queue queue = session.createQueue("myQueue");
@@ -164,13 +164,13 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase
         }
     }
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testReceiveAndThenResendBasicObjectMessageWithSerializedContent() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
             connection.start();
 
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
             Queue queue = session.createQueue("myQueue");
@@ -226,11 +226,11 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase
 
     //==== AMQP type system encoding ====
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testSendBasicObjectMessageWithAmqpTypedContent() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -263,13 +263,13 @@ public class ObjectMessageIntegrationTest extends QpidJmsTestCase
         }
     }
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testRecieveBasicObjectMessageWithAmqpTypedContentAndJMSMessageTypeAnnotation() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
             connection.start();
 
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
             Queue queue = session.createQueue("myQueue");
