@@ -57,11 +57,11 @@ import org.junit.Test;
 public class ProducerIntegrationTest extends QpidJmsTestCase {
     private final IntegrationTestFixture testFixture = new IntegrationTestFixture();
 
-    @Test(timeout = 10000)
+    @Test(timeout = 20000)
     public void testCloseSender() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -75,11 +75,11 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 10000)
+    @Test(timeout = 20000)
     public void testDefaultDeliveryModeProducesDurableMessages() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -104,11 +104,11 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 10000)
+    @Test(timeout = 20000)
     public void testProducerOverridesMessageDeliveryMode() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -142,11 +142,11 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
      * Test that when a message is sent the JMSDestination header is set to
      * the Destination used by the producer.
      */
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testSendingMessageSetsJMSDestination() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -177,11 +177,11 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 10000)
+    @Test(timeout = 20000)
     public void testSendingMessageSetsJMSTimestamp() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -221,11 +221,11 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
      * Test that after sending a message with the disableMessageTimestamp hint set, the
      * message object has a 0 JMSTimestamp value, and no creation-time field value was set.
      */
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testSendingMessageWithDisableMessageTimestampHint() throws Exception {
         try(TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -258,11 +258,11 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 10000)
+    @Test(timeout = 20000)
     public void testSendingMessageSetsJMSExpirationRelatedAbsoluteExpiryAndTtlFields() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -274,7 +274,7 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
             long ttl = 100_000;
 
             Date expirationLower = new Date(currentTime + ttl);
-            Date expirationUpper = new Date(currentTime + ttl + 3000);
+            Date expirationUpper = new Date(currentTime + ttl + 5000);
 
             // Create matcher to expect the absolute-expiry-time field of the properties section to
             // be set to a value greater than 'now'+ttl, within a delta.
@@ -302,12 +302,12 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 10000)
+    @Test(timeout = 20000)
     public void testSendingMessageWithJMS_AMQP_TTLSetPositive() throws Exception {
         sendingMessageWithJMS_AMQP_TTLSetTestImpl(100_000, 20_000);
     }
 
-    @Test(timeout = 10000)
+    @Test(timeout = 20000)
     public void testSendingMessageWithJMS_AMQP_TTLSetZero() throws Exception {
         sendingMessageWithJMS_AMQP_TTLSetTestImpl(50_000, 0);
     }
@@ -315,7 +315,7 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
     public void sendingMessageWithJMS_AMQP_TTLSetTestImpl(long jmsTtl, long amqpTtl) throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -363,11 +363,11 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
      * Test that when a message is sent with default priority of 4, the emitted AMQP message has no value in the header
      * priority field, since the default for that field is already 4.
      */
-    @Test(timeout = 10000)
+    @Test(timeout = 20000)
     public void testDefaultPriorityProducesMessagesWithoutPriorityField() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -399,11 +399,11 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
      * Test that when a message is sent with a non-default priority, the emitted AMQP message has that value in the
      * header priority field, and the JMS message has had JMSPriority set.
      */
-    @Test(timeout = 10000)
+    @Test(timeout = 20000)
     public void testNonDefaultPriorityProducesMessagesWithPriorityFieldAndSetsJMSPriority() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -437,11 +437,11 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
      * Test that upon sending a message, the sender sets the JMSMessageID on the Message object,
      * and that the value is included in the AMQP message sent by the client.
      */
-    @Test(timeout = 10000)
+    @Test(timeout = 20000)
     public void testSendingMessageSetsJMSMessageID() throws Exception {
         try(TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -483,11 +483,11 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
      * Test that after sending a message with the disableMessageID hint set, the message
      * object has a null JMSMessageID value, and no message-id field value was set.
      */
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testSendingMessageWithDisableMessageIDHint() throws Exception {
         try(TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             testPeer.expectSenderAttach();
 
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -520,14 +520,14 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 5000)
+    @Test(timeout = 20000)
     public void testRemotelyCloseProducer() throws Exception {
         final String BREAD_CRUMB = "ErrorMessage";
 
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
 
-            testPeer.expectBegin(true);
+            testPeer.expectBegin();
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
 
             // Create a producer, then remotely end it afterwards.
@@ -555,11 +555,36 @@ public class ProducerIntegrationTest extends QpidJmsTestCase {
                     }
                     return false;
                 }
-            }, 2000, 10));
+            }, 10000, 10));
 
             // Try closing it explicitly, should effectively no-op in client.
             // The test peer will throw during close if it sends anything.
             producer.close();
         }
     }
+
+    @Test(timeout = 20000)
+    public void testSendWhenLinkCreditIsDelayed() throws Exception {
+        try(TestAmqpPeer testPeer = new TestAmqpPeer();) {
+            Connection connection = testFixture.establishConnecton(testPeer, "?amqp.traceFrames=true&amqp.traceBytes=true");
+            testPeer.expectBegin();
+
+            Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
+            String queueName = "myQueue";
+            Queue queue = session.createQueue(queueName);
+
+            Message message = session.createTextMessage("text");
+            TransferPayloadCompositeMatcher messageMatcher = new TransferPayloadCompositeMatcher();
+
+            // Expect the producer to attach. Delay sending credit when it does.
+            testPeer.expectSenderAttach(100);
+
+            testPeer.expectTransfer(messageMatcher);
+
+            MessageProducer producer = session.createProducer(queue);
+
+            producer.send(message);
+            testPeer.waitForAllHandlersToComplete(1000);
+        }
+    }
 }
