@@ -35,8 +35,8 @@ import javax.jms.MessageNotReadableException;
 import javax.jms.MessageNotWriteableException;
 
 import org.apache.qpid.jms.message.facade.JmsBytesMessageFacade;
-import org.apache.qpid.jms.message.facade.defaults.JmsDefaultBytesMessageFacade;
-import org.apache.qpid.jms.message.facade.defaults.JmsDefaultMessageFactory;
+import org.apache.qpid.jms.message.facade.test.JmsTestBytesMessageFacade;
+import org.apache.qpid.jms.message.facade.test.JmsTestMessageFactory;
 import org.junit.Test;
 import org.mockito.Mockito;
 
@@ -47,7 +47,7 @@ public class JmsBytesMessageTest {
 
     private static final int END_OF_STREAM = -1;
 
-    private final JmsMessageFactory factory = new JmsDefaultMessageFactory();
+    private final JmsMessageFactory factory = new JmsTestMessageFactory();
 
     @Test
     public void testToString() throws Exception {
@@ -89,7 +89,7 @@ public class JmsBytesMessageTest {
     @Test
     public void testReadBytesUsingReceivedMessageWithBodyReturnsBytes() throws Exception {
         byte[] content = "myBytesData".getBytes();
-        JmsDefaultBytesMessageFacade facade = new JmsDefaultBytesMessageFacade(content);
+        JmsTestBytesMessageFacade facade = new JmsTestBytesMessageFacade(content);
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
         bytesMessage.onDispatch();
@@ -113,7 +113,7 @@ public class JmsBytesMessageTest {
     @Test(expected = MessageNotWriteableException.class)
     public void testReceivedBytesMessageThrowsMessageNotWriteableExceptionOnWriteBytes() throws Exception {
         byte[] content = "myBytesData".getBytes();
-        JmsDefaultBytesMessageFacade facade = new JmsDefaultBytesMessageFacade(content);
+        JmsTestBytesMessageFacade facade = new JmsTestBytesMessageFacade(content);
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
         bytesMessage.onDispatch();
@@ -138,7 +138,7 @@ public class JmsBytesMessageTest {
     @Test
     public void testClearBodyOnReceivedBytesMessageMakesMessageWritable() throws Exception {
         byte[] content = "myBytesData".getBytes();
-        JmsDefaultBytesMessageFacade facade = new JmsDefaultBytesMessageFacade(content);
+        JmsTestBytesMessageFacade facade = new JmsTestBytesMessageFacade(content);
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
         bytesMessage.onDispatch();
@@ -154,7 +154,7 @@ public class JmsBytesMessageTest {
     @Test
     public void testClearBodyOnReceivedBytesMessageClearsFacadeInputStream() throws Exception {
         byte[] content = "myBytesData".getBytes();
-        JmsDefaultBytesMessageFacade facade = new JmsDefaultBytesMessageFacade(content);
+        JmsTestBytesMessageFacade facade = new JmsTestBytesMessageFacade(content);
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
         bytesMessage.onDispatch();
@@ -173,7 +173,7 @@ public class JmsBytesMessageTest {
     @Test
     public void testGetBodyLengthOnClearedReceivedMessageThrowsMessageNotReadableException() throws Exception {
         byte[] content = "myBytesData".getBytes();
-        JmsDefaultBytesMessageFacade facade = new JmsDefaultBytesMessageFacade(content);
+        JmsTestBytesMessageFacade facade = new JmsTestBytesMessageFacade(content);
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
         bytesMessage.onDispatch();
@@ -195,7 +195,7 @@ public class JmsBytesMessageTest {
     @Test
     public void testResetOnReceivedBytesMessageResetsMarker() throws Exception {
         byte[] content = "myBytesData".getBytes();
-        JmsDefaultBytesMessageFacade facade = new JmsDefaultBytesMessageFacade(content);
+        JmsTestBytesMessageFacade facade = new JmsTestBytesMessageFacade(content);
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
         bytesMessage.onDispatch();
@@ -221,7 +221,7 @@ public class JmsBytesMessageTest {
     @Test
     public void testResetOnNewlyPopulatedBytesMessageResetsMarkerAndMakesReadable() throws Exception {
         byte[] content = "myBytesData".getBytes();
-        JmsDefaultBytesMessageFacade facade = new JmsDefaultBytesMessageFacade(content);
+        JmsTestBytesMessageFacade facade = new JmsTestBytesMessageFacade(content);
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
 
