@@ -1864,12 +1864,6 @@ public class AmqpJmsMessageFacadeTest extends AmqpJmsMessageTypesTestCase  {
         assertEquals(0, message.getTimestamp());
     }
 
-    @Test
-    public void testIsEmpty() {
-        AmqpJmsMessageFacade message = createNewMessageFacade();
-        assertTrue(message.isEmpty());
-    }
-
     @Test
     public void testClearBodyRemoveMessageBody() {
         Message message = Mockito.mock(Message.class);
