@@ -93,12 +93,18 @@ import org.junit.Assert;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-// TODO should expectXXXYYYZZZ methods just be expect(matcher)?
 public class TestAmqpPeer implements AutoCloseable
 {
     private static final Logger LOGGER = LoggerFactory.getLogger(TestAmqpPeer.class.getName());
+
+    private static final Symbol ANONYMOUS = Symbol.valueOf("ANONYMOUS");
+    private static final Symbol EXTERNAL = Symbol.valueOf("EXTERNAL");
+    private static final Symbol PLAIN = Symbol.valueOf("PLAIN");
+    private static final UnsignedByte SASL_OK = UnsignedByte.valueOf((byte)0);
+    private static final UnsignedByte SASL_FAIL_AUTH = UnsignedByte.valueOf((byte)1);
     private static final int CONNECTION_CHANNEL = 0;
 
+    private volatile AssertionError _firstAssertionError = null;
     private final TestAmqpPeerRunner _driverRunnable;
     private final Thread _driverThread;
 
@@ -151,6 +157,18 @@ public class TestAmqpPeer implements AutoCloseable
         }
         finally
         {
+            AssertionError ae = _firstAssertionError;
+            if(ae != null)
+            {
+                String message = "Assertion failure during test run";
+                if(ae.getMessage() != null)
+                {
+                    message += ": " + ae.getMessage();
+                }
+
+                throw new AssertionError(message, _firstAssertionError);
+            }
+
             Throwable throwable = getThrowable();
             if(throwable == null)
             {
@@ -201,16 +219,13 @@ public class TestAmqpPeer implements AutoCloseable
         return _emptyFrameCount;
     }
 
-    public void receiveHeader(byte[] header)
+    void receiveHeader(byte[] header)
     {
         Handler handler = getFirstHandler();
         if(handler instanceof HeaderHandler)
         {
             ((HeaderHandler)handler).header(header,this);
-            if(handler.isComplete())
-            {
-                removeFirstHandler();
-            }
+            removeFirstHandler();
         }
         else
         {
@@ -218,16 +233,13 @@ public class TestAmqpPeer implements AutoCloseable
         }
     }
 
-    public void receiveFrame(int type, int channel, DescribedType describedType, Binary payload)
+    void receiveFrame(int type, int channel, DescribedType describedType, Binary payload)
     {
         Handler handler = getFirstHandler();
         if(handler instanceof FrameHandler)
         {
             ((FrameHandler)handler).frame(type, channel, describedType, payload, this);
-            if(handler.isComplete())
-            {
-                removeFirstHandler();
-            }
+            removeFirstHandler();
         }
         else
         {
@@ -235,7 +247,7 @@ public class TestAmqpPeer implements AutoCloseable
         }
     }
 
-    public void receiveEmptyFrame(int type, int channel)
+    void receiveEmptyFrame(int type, int channel)
     {
         _emptyFrameCount ++;
         LOGGER.debug("Received empty frame");
@@ -308,10 +320,10 @@ public class TestAmqpPeer implements AutoCloseable
 
     public void sendEmptyFrame(boolean deferWrite)
     {
-        sendFrame(FrameType.AMQP, 0, null, null, deferWrite);
+        sendFrame(FrameType.AMQP, 0, null, null, deferWrite, 0);
     }
 
-    public void sendFrame(FrameType type, int channel, DescribedType frameDescribedType, Binary framePayload, boolean deferWrite)
+    void sendFrame(FrameType type, int channel, DescribedType frameDescribedType, Binary framePayload, boolean deferWrite, long sendDelay)
     {
         if(channel < 0)
         {
@@ -319,6 +331,18 @@ public class TestAmqpPeer implements AutoCloseable
         }
 
         LOGGER.debug("About to send: {}", frameDescribedType);
+
+        if(sendDelay > 0)
+        {
+            LOGGER.debug("Delaying send by {} ms", sendDelay);
+            try {
+                Thread.sleep(sendDelay);
+            } catch (InterruptedException e) {
+                Thread.currentThread().interrupt();
+                throw new RuntimeException("Interrupted before send", e);
+            }
+        }
+
         byte[] output = AmqpDataFramer.encodeFrame(type, channel, frameDescribedType, framePayload);
 
         if(deferWrite && _deferredBytes == null)
@@ -364,57 +388,31 @@ public class TestAmqpPeer implements AutoCloseable
         return openFrame;
     }
 
-    public void expectFailingSaslConnect(Symbol[] serverMechs, Symbol clientSelectedMech)
+    public void expectSaslConnect(Symbol mechanism, Matcher<Binary> initialResponseMatcher, Symbol[] desiredCapabilities, Symbol[] serverCapabilities,
+                                    Matcher<?> clientPropertiesMatcher, Map<Symbol, Object> serverProperties, Matcher<?> idleTimeoutMatcher, Matcher<?> hostnameMatcher)
     {
-        SaslMechanismsFrame saslMechanismsFrame = new SaslMechanismsFrame().setSaslServerMechanisms(serverMechs);
-        addHandler(new HeaderHandlerImpl(AmqpHeader.SASL_HEADER, AmqpHeader.SASL_HEADER,
-                                            new FrameSender(
-                                                    this, FrameType.SASL, 0,
-                                                    saslMechanismsFrame, null)));
-
-        SaslInitMatcher saslInitMatcher = new SaslInitMatcher().withMechanism(equalTo(clientSelectedMech));
-        saslInitMatcher.onSuccess(new AmqpPeerRunnable()
-        {
-            @Override
-            public void run()
-            {
-                TestAmqpPeer.this.sendFrame(
-                        FrameType.SASL, 0,
-                        new SaslOutcomeFrame().setCode(UnsignedByte.valueOf((byte)1)),
-                        null,
-                        false);
-                _driverRunnable.expectHeader();
-            }
-        });
-        addHandler(saslInitMatcher);
-    }
-
-    public void expectAnonymousConnect(boolean authorize)
-    {
-        expectAnonymousConnect(authorize, null, null);
-    }
-
-    public void expectAnonymousConnect(boolean authorize, Matcher<?> idleTimeoutMatcher, Matcher<?> hostnameMatcher)
-    {
-        SaslMechanismsFrame saslMechanismsFrame = new SaslMechanismsFrame().setSaslServerMechanisms(Symbol.valueOf("ANONYMOUS"));
+        SaslMechanismsFrame saslMechanismsFrame = new SaslMechanismsFrame().setSaslServerMechanisms(mechanism);
         addHandler(new HeaderHandlerImpl(AmqpHeader.SASL_HEADER, AmqpHeader.SASL_HEADER,
                                             new FrameSender(
                                                     this, FrameType.SASL, 0,
                                                     saslMechanismsFrame, null)));
 
         SaslInitMatcher saslInitMatcher = new SaslInitMatcher()
-            .withMechanism(equalTo(Symbol.valueOf("ANONYMOUS")))
-            .withInitialResponse(equalTo(new Binary(new byte[0])))
-            .onSuccess(new AmqpPeerRunnable()
+            .withMechanism(equalTo(mechanism))
+            .withInitialResponse(initialResponseMatcher)
+            .onCompletion(new AmqpPeerRunnable()
             {
                 @Override
                 public void run()
                 {
                     TestAmqpPeer.this.sendFrame(
                             FrameType.SASL, 0,
-                            new SaslOutcomeFrame().setCode(UnsignedByte.valueOf((byte)0)),
+                            new SaslOutcomeFrame().setCode(SASL_OK),
                             null,
-                            false);
+                            false, 0);
+
+                    // Now that we processed the SASL layer AMQP header, reset the
+                    // peer to expect the non-SASL AMQP header.
                     _driverRunnable.expectHeader();
                 }
             });
@@ -428,107 +426,6 @@ public class TestAmqpPeer implements AutoCloseable
 
         addHandler(new HeaderHandlerImpl(AmqpHeader.HEADER, AmqpHeader.HEADER));
 
-        OpenFrame openFrame = createOpenFrame();
-
-        OpenMatcher openMatcher = new OpenMatcher()
-            .withContainerId(notNullValue(String.class))
-            .onSuccess(new FrameSender(
-                    this, FrameType.AMQP, 0,
-                    openFrame,
-                    null));
-
-        if(idleTimeoutMatcher !=null)
-        {
-            openMatcher.withIdleTimeOut(idleTimeoutMatcher);
-        }
-
-        if(hostnameMatcher != null)
-        {
-            openMatcher.withHostname(hostnameMatcher);
-        }
-
-        addHandler(openMatcher);
-    }
-
-    public void expectExternalConnect()
-    {
-        if(!_driverRunnable.isNeedClientCert()) {
-            throw new IllegalStateException("Need client cert must be enabled");
-        }
-
-        SaslMechanismsFrame saslMechanismsFrame = new SaslMechanismsFrame().setSaslServerMechanisms(Symbol.valueOf("EXTERNAL"));
-        addHandler(new HeaderHandlerImpl(AmqpHeader.SASL_HEADER, AmqpHeader.SASL_HEADER,
-                                            new FrameSender(
-                                                    this, FrameType.SASL, 0,
-                                                    saslMechanismsFrame, null)));
-
-        addHandler(new SaslInitMatcher()
-            .withMechanism(equalTo(Symbol.valueOf("EXTERNAL")))
-            .withInitialResponse(equalTo(new Binary(new byte[0])))
-            .onSuccess(new AmqpPeerRunnable()
-            {
-                @Override
-                public void run()
-                {
-                    TestAmqpPeer.this.sendFrame(
-                            FrameType.SASL, 0,
-                            new SaslOutcomeFrame().setCode(UnsignedByte.valueOf((byte)0)),
-                            null,
-                            false);
-                    _driverRunnable.expectHeader();
-                }
-            }));
-
-        addHandler(new HeaderHandlerImpl(AmqpHeader.HEADER, AmqpHeader.HEADER));
-
-        OpenFrame openFrame = createOpenFrame();
-
-        addHandler(new OpenMatcher()
-            .withContainerId(notNullValue(String.class))
-            .onSuccess(new FrameSender(
-                    this, FrameType.AMQP, 0,
-                    openFrame,
-                    null)));
-    }
-
-    public void expectPlainConnect(String username, String password, Symbol[] serverCapabilities, Map<Symbol, Object> serverProperties)
-    {
-        expectPlainConnect(username, password, new Symbol[] { AmqpSupport.SOLE_CONNECTION_CAPABILITY }, serverCapabilities, serverProperties);
-    }
-
-    public void expectPlainConnect(String username, String password, Symbol[] desiredCapabilities, Symbol[] serverCapabilities, Map<Symbol, Object> serverProperties)
-    {
-        SaslMechanismsFrame saslMechanismsFrame = new SaslMechanismsFrame().setSaslServerMechanisms(Symbol.valueOf("PLAIN"));
-        addHandler(new HeaderHandlerImpl(AmqpHeader.SASL_HEADER, AmqpHeader.SASL_HEADER,
-                                            new FrameSender(
-                                                    this, FrameType.SASL, 0,
-                                                    saslMechanismsFrame, null)));
-
-        byte[] usernameBytes = username.getBytes();
-        byte[] passwordBytes = password.getBytes();
-        byte[] data = new byte[usernameBytes.length+passwordBytes.length+2];
-        System.arraycopy(usernameBytes, 0, data, 1, usernameBytes.length);
-        System.arraycopy(passwordBytes, 0, data, 2 + usernameBytes.length, passwordBytes.length);
-
-        addHandler(new SaslInitMatcher()
-            .withMechanism(equalTo(Symbol.valueOf("PLAIN")))
-            .withInitialResponse(equalTo(new Binary(data)))
-            .onSuccess(new AmqpPeerRunnable()
-            {
-                @Override
-                public void run()
-                {
-                    TestAmqpPeer.this.sendFrame(
-                            FrameType.SASL, 0,
-                            new SaslOutcomeFrame().setCode(UnsignedByte.valueOf((byte)0)),
-                            null,
-                            false);
-                    _driverRunnable.expectHeader();
-                }
-            }));
-
-        addHandler(new HeaderHandlerImpl(AmqpHeader.HEADER, AmqpHeader.HEADER));
-
         OpenFrame open = createOpenFrame();
         if(serverCapabilities != null)
         {
@@ -542,58 +439,139 @@ public class TestAmqpPeer implements AutoCloseable
 
         OpenMatcher openMatcher = new OpenMatcher()
             .withContainerId(notNullValue(String.class))
-            .onSuccess(new FrameSender(
+            .onCompletion(new FrameSender(
                     this, FrameType.AMQP, 0,
                     open,
                     null));
 
-        if (desiredCapabilities != null) {
+        if (desiredCapabilities != null)
+        {
             openMatcher.withDesiredCapabilities(arrayContaining(desiredCapabilities));
-        } else {
+        }
+        else
+        {
             openMatcher.withDesiredCapabilities(nullValue());
         }
 
+        if(idleTimeoutMatcher !=null)
+        {
+            openMatcher.withIdleTimeOut(idleTimeoutMatcher);
+        }
+
+        if(hostnameMatcher != null)
+        {
+            openMatcher.withHostname(hostnameMatcher);
+        }
+
+        if(clientPropertiesMatcher != null) {
+            openMatcher.withProperties(clientPropertiesMatcher);
+        }
+
         addHandler(openMatcher);
     }
 
-    // TODO - Reject any incoming connection using the supplied information
-    public void rejectConnect(Symbol errorType, String errorMessage, Map<Symbol, Object> errorInfo) {
-        SaslMechanismsFrame saslMechanismsFrame = new SaslMechanismsFrame().setSaslServerMechanisms(Symbol.valueOf("ANONYMOUS"));
+    public void expectSaslPlainConnect(String username, String password, Symbol[] serverCapabilities, Map<Symbol, Object> serverProperties)
+    {
+        expectSaslPlainConnect(username, password, new Symbol[] { AmqpSupport.SOLE_CONNECTION_CAPABILITY }, serverCapabilities, serverProperties);
+    }
+
+    public void expectSaslPlainConnect(String username, String password, Symbol[] desiredCapabilities, Symbol[] serverCapabilities, Map<Symbol, Object> serverProperties)
+    {
+        byte[] usernameBytes = username.getBytes();
+        byte[] passwordBytes = password.getBytes();
+        byte[] data = new byte[usernameBytes.length+passwordBytes.length+2];
+        System.arraycopy(usernameBytes, 0, data, 1, usernameBytes.length);
+        System.arraycopy(passwordBytes, 0, data, 2 + usernameBytes.length, passwordBytes.length);
+
+        Matcher<Binary> initialResponseMatcher = equalTo(new Binary(data));
+
+        expectSaslConnect(PLAIN, initialResponseMatcher, desiredCapabilities, serverCapabilities, null, serverProperties, null, null);
+    }
+
+    public void expectSaslExternalConnect()
+    {
+        if(!_driverRunnable.isNeedClientCert())
+        {
+            throw new IllegalStateException("need-client-cert must be enabled on the test peer");
+        }
+
+        expectSaslConnect(EXTERNAL, equalTo(new Binary(new byte[0])), new Symbol[] { AmqpSupport.SOLE_CONNECTION_CAPABILITY }, null, null, null, null, null);
+    }
+
+    public void expectSaslAnonymousConnect()
+    {
+        expectSaslAnonymousConnect(null, null);
+    }
+
+    public void expectSaslAnonymousConnect(Matcher<?> idleTimeoutMatcher, Matcher<?> hostnameMatcher)
+    {
+        expectSaslAnonymousConnect(idleTimeoutMatcher, hostnameMatcher, null, null);
+    }
+
+    public void expectSaslAnonymousConnect(Matcher<?> idleTimeoutMatcher, Matcher<?> hostnameMatcher, Matcher<?> propertiesMatcher, Map<Symbol, Object> serverProperties)
+    {
+        expectSaslConnect(ANONYMOUS, equalTo(new Binary(new byte[0])), new Symbol[] { AmqpSupport.SOLE_CONNECTION_CAPABILITY }, null, propertiesMatcher, serverProperties, idleTimeoutMatcher, hostnameMatcher);
+    }
+
+    public void expectFailingSaslConnect(Symbol[] serverMechs, Symbol clientSelectedMech)
+    {
+        SaslMechanismsFrame saslMechanismsFrame = new SaslMechanismsFrame().setSaslServerMechanisms(serverMechs);
         addHandler(new HeaderHandlerImpl(AmqpHeader.SASL_HEADER, AmqpHeader.SASL_HEADER,
                                             new FrameSender(
                                                     this, FrameType.SASL, 0,
                                                     saslMechanismsFrame, null)));
 
-        addHandler(new SaslInitMatcher()
-            .withMechanism(equalTo(Symbol.valueOf("ANONYMOUS")))
-            .withInitialResponse(equalTo(new Binary(new byte[0])))
-            .onSuccess(new AmqpPeerRunnable()
+        SaslInitMatcher saslInitMatcher = new SaslInitMatcher().withMechanism(equalTo(clientSelectedMech));
+        saslInitMatcher.onCompletion(new AmqpPeerRunnable()
+        {
+            @Override
+            public void run()
             {
-                @Override
-                public void run()
-                {
-                    TestAmqpPeer.this.sendFrame(
-                            FrameType.SASL, 0,
-                            new SaslOutcomeFrame().setCode(UnsignedByte.valueOf((byte)0)),
-                            null,
-                            false);
-                    _driverRunnable.expectHeader();
-                }
-            }));
+                TestAmqpPeer.this.sendFrame(
+                        FrameType.SASL, 0,
+                        new SaslOutcomeFrame().setCode(SASL_FAIL_AUTH),
+                        null,
+                        false, 0);
+                _driverRunnable.expectHeader();
+            }
+        });
+        addHandler(saslInitMatcher);
+    }
 
+    /**
+     * Expect a connection that does not use a SASL layer, but proceeds straight
+     * to the AMQP connection (useful to skip a stage for connections that don't
+     * require SASL, e.g. because of anonymous or client certificate authentication).
+     */
+    public void expectSaslLayerDisabledConnect(Matcher<?> maxFrameSizeMatcher)
+    {
         addHandler(new HeaderHandlerImpl(AmqpHeader.HEADER, AmqpHeader.HEADER));
 
-        Map<Symbol, Object> properties = new HashMap<Symbol, Object>();
-        properties.put(Symbol.valueOf("amqp:connection-establishment-failed"), true);
+        OpenFrame openFrame = createOpenFrame();
 
-        OpenFrame open = createOpenFrame();
-        open.setProperties(properties);
+        OpenMatcher openMatcher = new OpenMatcher()
+            .withContainerId(notNullValue(String.class));
 
-        addHandler(new OpenMatcher()
-            .withContainerId(notNullValue(String.class))
-            .onSuccess(new FrameSender(this, FrameType.AMQP, CONNECTION_CHANNEL, open, null)));
+        if(maxFrameSizeMatcher != null) {
+            openMatcher.withMaxFrameSize(maxFrameSizeMatcher);
+        }
 
-        // Now generate the Close with the supplied error
+        openMatcher.onCompletion(new FrameSender(
+                    this, FrameType.AMQP, 0,
+                    openFrame,
+                    null));
+
+        addHandler(openMatcher);
+    }
+
+    public void rejectConnect(Symbol errorType, String errorMessage, Map<Symbol, Object> errorInfo) {
+        // Expect a connection, establish through the SASL negotiation and sending of the Open frame
+        Map<Symbol, Object> serverProperties = new HashMap<Symbol, Object>();
+        serverProperties.put(AmqpSupport.CONNECTION_OPEN_FAILED, true);
+
+        expectSaslAnonymousConnect(null, null, null, serverProperties);
+
+        // Now generate the Close frame with the supplied error
         final CloseFrame closeFrame = new CloseFrame();
         if (errorType != null) {
             org.apache.qpid.jms.test.testpeer.describedtypes.Error detachError = new org.apache.qpid.jms.test.testpeer.describedtypes.Error();
@@ -603,6 +581,7 @@ public class TestAmqpPeer implements AutoCloseable
             closeFrame.setError(detachError);
         }
 
+        // Update the handler to send the Close frame after the Open frame.
         CompositeAmqpPeerRunnable comp = insertCompsiteActionForLastHandler();
         final FrameSender closeSender = new FrameSender(this, FrameType.AMQP, CONNECTION_CHANNEL, closeFrame, null);
         comp.add(closeSender);
@@ -619,7 +598,7 @@ public class TestAmqpPeer implements AutoCloseable
     {
         CloseMatcher closeMatcher = new CloseMatcher().withError(errorMatcher);
         if(sendReply) {
-            closeMatcher.onSuccess(new FrameSender(this, FrameType.AMQP, 0,
+            closeMatcher.onCompletion(new FrameSender(this, FrameType.AMQP, 0,
                     new CloseFrame(),
                     null));
         }
@@ -627,19 +606,25 @@ public class TestAmqpPeer implements AutoCloseable
         addHandler(closeMatcher);
     }
 
-    public void expectHeaderAndOpen()
+    public void expectBegin()
     {
-        addHandler(new HeaderHandlerImpl(AmqpHeader.HEADER, AmqpHeader.HEADER));
-        addHandler(new OpenMatcher());
+        expectBegin(notNullValue());
     }
 
-    public void expectBegin(boolean expectSessionFlow)
+    public void expectBegin(Matcher<?> outgoingWindowMatcher)
     {
         final BeginMatcher beginMatcher = new BeginMatcher()
                 .withRemoteChannel(nullValue())
                 .withNextOutgoingId(equalTo(UnsignedInteger.ONE))
-                .withIncomingWindow(notNullValue())
-                .withOutgoingWindow(notNullValue());
+                .withIncomingWindow(notNullValue());
+        if(outgoingWindowMatcher != null)
+        {
+            beginMatcher.withOutgoingWindow(notNullValue());
+        }
+        else
+        {
+            beginMatcher.withOutgoingWindow(outgoingWindowMatcher);
+        }
 
         // The response will have its remoteChannel field dynamically set based on incoming value
         final BeginFrame beginResponse = new BeginFrame()
@@ -663,14 +648,9 @@ public class TestAmqpPeer implements AutoCloseable
                 _lastInitiatedChannel = actualChannel;
             }
         });
-        beginMatcher.onSuccess(beginResponseSender);
+        beginMatcher.onCompletion(beginResponseSender);
 
         addHandler(beginMatcher);
-
-        if(expectSessionFlow)
-        {
-            expectSessionFlow();
-        }
     }
 
     public void expectEnd()
@@ -695,7 +675,7 @@ public class TestAmqpPeer implements AutoCloseable
                     frameSender.setChannel(endMatcher.getActualChannel());
                 }
             });
-            endMatcher.onSuccess(frameSender);
+            endMatcher.onCompletion(frameSender);
         }
 
         addHandler(endMatcher);
@@ -827,7 +807,7 @@ public class TestAmqpPeer implements AutoCloseable
             composite.add(detachResonseSender);
         }
 
-        attachMatcher.onSuccess(composite);
+        attachMatcher.onCompletion(composite);
 
         addHandler(attachMatcher);
     }
@@ -837,6 +817,11 @@ public class TestAmqpPeer implements AutoCloseable
         expectSenderAttach(notNullValue(), false, false);
     }
 
+    public void expectSenderAttach(long creditFlowDelay)
+    {
+        expectSenderAttach(notNullValue(), notNullValue(), false, false, creditFlowDelay, null, null);
+    }
+
     public void expectSenderAttach(final Matcher<?> targetMatcher, final boolean refuseLink, boolean deferAttachResponseWrite)
     {
         expectSenderAttach(notNullValue(), targetMatcher, refuseLink, deferAttachResponseWrite);
@@ -844,10 +829,10 @@ public class TestAmqpPeer implements AutoCloseable
 
     public void expectSenderAttach(final Matcher<?> sourceMatcher, final Matcher<?> targetMatcher, final boolean refuseLink, boolean deferAttachResponseWrite)
     {
-        expectSenderAttach(notNullValue(), targetMatcher, refuseLink, deferAttachResponseWrite, null, null);
+        expectSenderAttach(notNullValue(), targetMatcher, refuseLink, deferAttachResponseWrite, 0, null, null);
     }
 
-    public void expectSenderAttach(final Matcher<?> sourceMatcher, final Matcher<?> targetMatcher, final boolean refuseLink, boolean deferAttachResponseWrite, Symbol errorType, String errorMessage)
+    public void expectSenderAttach(final Matcher<?> sourceMatcher, final Matcher<?> targetMatcher, final boolean refuseLink, boolean deferAttachResponseWrite, long creditFlowDelay, Symbol errorType, String errorMessage)
     {
         final AttachMatcher attachMatcher = new AttachMatcher()
                 .withName(notNullValue())
@@ -910,6 +895,7 @@ public class TestAmqpPeer implements AutoCloseable
                 flowFrame.setDeliveryCount(attachMatcher.getReceivedInitialDeliveryCount());
             }
         });
+        flowFrameSender.setSendDelay(creditFlowDelay);
 
         final DetachFrame detachResponse = new DetachFrame().setClosed(true);
         if (errorType != null)
@@ -941,7 +927,7 @@ public class TestAmqpPeer implements AutoCloseable
             composite.add(flowFrameSender);
         }
 
-        attachMatcher.onSuccess(composite);
+        attachMatcher.onCompletion(composite);
 
         addHandler(attachMatcher);
     }
@@ -1034,7 +1020,7 @@ public class TestAmqpPeer implements AutoCloseable
             composite.add(detachResonseSender);
         }
 
-        attachMatcher.onSuccess(composite);
+        attachMatcher.onCompletion(composite);
 
         addHandler(attachMatcher);
     }
@@ -1090,7 +1076,7 @@ public class TestAmqpPeer implements AutoCloseable
                 }
             });
 
-            detachMatcher.onSuccess(detachResponseSender);
+            detachMatcher.onCompletion(detachResponseSender);
         }
 
         addHandler(detachMatcher);
@@ -1241,7 +1227,7 @@ public class TestAmqpPeer implements AutoCloseable
         }
 
         if(addComposite) {
-            flowMatcher.onSuccess(composite);
+            flowMatcher.onCompletion(composite);
         }
 
         addHandler(flowMatcher);
@@ -1336,7 +1322,7 @@ public class TestAmqpPeer implements AutoCloseable
                 dispositionResponse.setFirst(transferMatcher.getReceivedDeliveryId());
             }
         });
-        transferMatcher.onSuccess(dispositionFrameSender);
+        transferMatcher.onCompletion(dispositionFrameSender);
 
         addHandler(transferMatcher);
     }
@@ -1521,11 +1507,11 @@ public class TestAmqpPeer implements AutoCloseable
     private CompositeAmqpPeerRunnable insertCompsiteActionForLastHandler() {
         CompositeAmqpPeerRunnable comp = new CompositeAmqpPeerRunnable();
         Handler h = getLastHandler();
-        AmqpPeerRunnable orig = h.getOnSuccessAction();
+        AmqpPeerRunnable orig = h.getOnCompletionAction();
         if (orig != null) {
             comp.add(orig);
         }
-        h.onSuccess(comp);
+        h.onCompletion(comp);
         return comp;
     }
 
@@ -1569,4 +1555,11 @@ public class TestAmqpPeer implements AutoCloseable
             comp.add(action);
         }
     }
+
+    void assertionFailed(AssertionError ae) {
+        if(_firstAssertionError == null)
+        {
+            _firstAssertionError = ae;
+        }
+    }
 }
